@@ -118,8 +118,21 @@ import aws_cdk.aws_lambda
 import aws_cdk.core
 
 
-class IotToLambda(aws_cdk.core.Construct, metaclass=jsii.JSIIMeta, jsii_type="@aws-solutions-constructs/aws-iot-lambda.IotToLambda"):
-    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, deploy_lambda: bool, iot_topic_rule_props: aws_cdk.aws_iot.CfnTopicRuleProps, existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function]=None, lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps]=None) -> None:
+class IotToLambda(
+    aws_cdk.core.Construct,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="@aws-solutions-constructs/aws-iot-lambda.IotToLambda",
+):
+    def __init__(
+        self,
+        scope: aws_cdk.core.Construct,
+        id: str,
+        *,
+        deploy_lambda: bool,
+        iot_topic_rule_props: aws_cdk.aws_iot.CfnTopicRuleProps,
+        existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
+        lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
+    ) -> None:
         """
         :param scope: - represents the scope for all the resources.
         :param id: - this is a a scope-unique id.
@@ -135,7 +148,12 @@ class IotToLambda(aws_cdk.core.Construct, metaclass=jsii.JSIIMeta, jsii_type="@a
         summary:
         :summary:: Constructs a new instance of the IotToLambda class.
         """
-        props = IotToLambdaProps(deploy_lambda=deploy_lambda, iot_topic_rule_props=iot_topic_rule_props, existing_lambda_obj=existing_lambda_obj, lambda_function_props=lambda_function_props)
+        props = IotToLambdaProps(
+            deploy_lambda=deploy_lambda,
+            iot_topic_rule_props=iot_topic_rule_props,
+            existing_lambda_obj=existing_lambda_obj,
+            lambda_function_props=lambda_function_props,
+        )
 
         jsii.create(IotToLambda, self, [scope, id, props])
 
@@ -150,9 +168,25 @@ class IotToLambda(aws_cdk.core.Construct, metaclass=jsii.JSIIMeta, jsii_type="@a
         return jsii.get(self, "lambdaFunction")
 
 
-@jsii.data_type(jsii_type="@aws-solutions-constructs/aws-iot-lambda.IotToLambdaProps", jsii_struct_bases=[], name_mapping={'deploy_lambda': 'deployLambda', 'iot_topic_rule_props': 'iotTopicRuleProps', 'existing_lambda_obj': 'existingLambdaObj', 'lambda_function_props': 'lambdaFunctionProps'})
-class IotToLambdaProps():
-    def __init__(self, *, deploy_lambda: bool, iot_topic_rule_props: aws_cdk.aws_iot.CfnTopicRuleProps, existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function]=None, lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps]=None) -> None:
+@jsii.data_type(
+    jsii_type="@aws-solutions-constructs/aws-iot-lambda.IotToLambdaProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "deploy_lambda": "deployLambda",
+        "iot_topic_rule_props": "iotTopicRuleProps",
+        "existing_lambda_obj": "existingLambdaObj",
+        "lambda_function_props": "lambdaFunctionProps",
+    },
+)
+class IotToLambdaProps:
+    def __init__(
+        self,
+        *,
+        deploy_lambda: bool,
+        iot_topic_rule_props: aws_cdk.aws_iot.CfnTopicRuleProps,
+        existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
+        lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
+    ) -> None:
         """
         :param deploy_lambda: Whether to create a new lambda function or use an existing lambda function. If set to false, you must provide a lambda function object as ``existingObj`` Default: - true
         :param iot_topic_rule_props: User provided CfnTopicRuleProps to override the defaults. Default: - None
@@ -162,14 +196,22 @@ class IotToLambdaProps():
         summary:
         :summary:: The properties for the IotToLambda class.
         """
-        if isinstance(iot_topic_rule_props, dict): iot_topic_rule_props = aws_cdk.aws_iot.CfnTopicRuleProps(**iot_topic_rule_props)
-        if isinstance(lambda_function_props, dict): lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
+        if isinstance(iot_topic_rule_props, dict):
+            iot_topic_rule_props = aws_cdk.aws_iot.CfnTopicRuleProps(
+                **iot_topic_rule_props
+            )
+        if isinstance(lambda_function_props, dict):
+            lambda_function_props = aws_cdk.aws_lambda.FunctionProps(
+                **lambda_function_props
+            )
         self._values = {
-            'deploy_lambda': deploy_lambda,
-            'iot_topic_rule_props': iot_topic_rule_props,
+            "deploy_lambda": deploy_lambda,
+            "iot_topic_rule_props": iot_topic_rule_props,
         }
-        if existing_lambda_obj is not None: self._values["existing_lambda_obj"] = existing_lambda_obj
-        if lambda_function_props is not None: self._values["lambda_function_props"] = lambda_function_props
+        if existing_lambda_obj is not None:
+            self._values["existing_lambda_obj"] = existing_lambda_obj
+        if lambda_function_props is not None:
+            self._values["lambda_function_props"] = lambda_function_props
 
     @builtins.property
     def deploy_lambda(self) -> bool:
@@ -180,7 +222,7 @@ class IotToLambdaProps():
         default
         :default: - true
         """
-        return self._values.get('deploy_lambda')
+        return self._values.get("deploy_lambda")
 
     @builtins.property
     def iot_topic_rule_props(self) -> aws_cdk.aws_iot.CfnTopicRuleProps:
@@ -189,7 +231,7 @@ class IotToLambdaProps():
         default
         :default: - None
         """
-        return self._values.get('iot_topic_rule_props')
+        return self._values.get("iot_topic_rule_props")
 
     @builtins.property
     def existing_lambda_obj(self) -> typing.Optional[aws_cdk.aws_lambda.Function]:
@@ -200,10 +242,12 @@ class IotToLambdaProps():
         default
         :default: - None
         """
-        return self._values.get('existing_lambda_obj')
+        return self._values.get("existing_lambda_obj")
 
     @builtins.property
-    def lambda_function_props(self) -> typing.Optional[aws_cdk.aws_lambda.FunctionProps]:
+    def lambda_function_props(
+        self,
+    ) -> typing.Optional[aws_cdk.aws_lambda.FunctionProps]:
         """Optional user provided props to override the default props.
 
         If ``deploy`` is set to true only then this property is required
@@ -211,7 +255,7 @@ class IotToLambdaProps():
         default
         :default: - Default props are used
         """
-        return self._values.get('lambda_function_props')
+        return self._values.get("lambda_function_props")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -220,7 +264,9 @@ class IotToLambdaProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'IotToLambdaProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "IotToLambdaProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 __all__ = [
